<?php
/*
Copyright (©) 2003-2013 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/
require_once ("../bootstrap/bootstrap.php");
$view = new Assets_View (__FILE__);
$menu_main = new Menu_Main ();
$view->view->mainmenu = $menu_main->create ();
$menu_user = new Menu_User ();
$view->view->usermenu = $menu_user->create ();
@$navigator = $_GET ['navigator'];
if ($navigator) {
  $view->view->display_navigator = true;
  $database_config_user = Database_Config_User::getInstance ();
  $bible = $database_config_user->getBible ();
  $view->view->navigationHtml = Navigation_Passage::getContainer ();
  $view->view->navigationCode = Navigation_Passage::code ($bible, true);
}
$view->render ("topbar.php");
?>
